@@ -29,10 +29,8 @@ BEGIN {
     );
 }
 
-use constant {
-    %ast_nodes,
-    %interpreter,
-};
+use constant \%ast_nodes;
+use constant \%interpreter;
 
 1;
 
@@ -48,7 +46,7 @@ Devel::Optic::Lens::Perlish::Constants
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 AUTHOR
 
